@@ -4,8 +4,8 @@ import (
 	"context"
 
 	"github.com/google/uuid"
+
 	"github.com/quay/clair/v4/notifier"
-	"github.com/quay/clair/v4/notifier/keymanager"
 )
 
 var _ Service = (*Mock)(nil)
@@ -14,8 +14,6 @@ var _ Service = (*Mock)(nil)
 type Mock struct {
 	Notifications_       func(ctx context.Context, id uuid.UUID, page *notifier.Page) ([]notifier.Notification, notifier.Page, error)
 	DeleteNotifications_ func(ctx context.Context, id uuid.UUID) error
-	KeyStore_            func(ctx context.Context) notifier.KeyStore
-	KeyManager_          func(ctx context.Context) *keymanager.Manager
 }
 
 func (m *Mock) Notifications(ctx context.Context, id uuid.UUID, page *notifier.Page) ([]notifier.Notification, notifier.Page, error) {
@@ -25,10 +23,3 @@ func (m *Mock) Notifications(ctx context.Context, id uuid.UUID, page *notifier.P
 func (m *Mock) DeleteNotifications(ctx context.Context, id uuid.UUID) error {
 	return m.DeleteNotifications_(ctx, id)
 }
-
-func (m *Mock) KeyStore(ctx context.Context) notifier.KeyStore {
-	return m.KeyStore_(ctx)
-}
-func (m *Mock) KeyManager(ctx context.Context) *keymanager.Manager {
-	return m.KeyManager_(ctx)
-}
